@@ -1,20 +1,8 @@
-/* This file is part of Step.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
-   Copyright (C) 2014 Inge Wallin        <inge@lysator.liu.se>
+/*.
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+    SPDX-FileCopyrightText: 2014 Inge Wallin <inge@lysator.liu.se>
 
-   Step is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   Step is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with Step; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "worldgraphics.h"
@@ -68,9 +56,9 @@ bool ItemCreator::sceneEvent(QEvent* event)
         _worldModel->simulationPause();
 
         _worldModel->beginMacro(i18n("Create %1", _worldModel->newItemName(_className)));
-        _item = _worldModel->createItem(_className); Q_ASSERT(_item != NULL);
+        _item = _worldModel->createItem(_className); Q_ASSERT(_item != nullptr);
         const StepCore::MetaProperty* property = _item->metaObject()->property(QStringLiteral("position"));
-        if(property != NULL) {
+        if(property != nullptr) {
             QGraphicsSceneMouseEvent* mouseEvent = static_cast<QGraphicsSceneMouseEvent*>(event);
             QPointF pos = mouseEvent->scenePos();
             QVariant vpos = QVariant::fromValue(StepGraphicsItem::pointToVector(pos));
@@ -110,7 +98,7 @@ bool AttachableItemCreator::sceneEvent(QEvent* event)
 {
     QGraphicsSceneMouseEvent* mouseEvent = static_cast<QGraphicsSceneMouseEvent*>(event);
 
-    if(event->type() == QEvent::GraphicsSceneMouseMove && _item == NULL) {
+    if(event->type() == QEvent::GraphicsSceneMouseMove && _item == nullptr) {
         _worldScene->snapHighlight(mouseEvent->scenePos(), _snapFlags, _snapTypes);
         return false;
 
@@ -118,7 +106,7 @@ bool AttachableItemCreator::sceneEvent(QEvent* event)
         QPointF pos = mouseEvent->scenePos();
         _worldModel->simulationPause();
         _worldModel->beginMacro(i18n("Create %1", _worldModel->newItemName(_className)));
-        _item = _worldModel->createItem(className()); Q_ASSERT(_item != NULL);
+        _item = _worldModel->createItem(className()); Q_ASSERT(_item != nullptr);
 
         if(_twoEnds) {
             _worldScene->snapItem(pos, _snapFlags, _snapTypes, StepGraphicsItem::Finished, _item, 1);
