@@ -1,19 +1,7 @@
-/* This file is part of StepCore library.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+/*
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
 
-   StepCore library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   StepCore library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with StepCore; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 /** \file motor.h
@@ -44,7 +32,7 @@ class LinearMotor : public Force
 
 public:
     /** Constructs LinearMotor */
-    explicit LinearMotor(Object* body = 0, const Vector2d& localPosition = Vector2d::Zero(),
+    explicit LinearMotor(Object* body = nullptr, const Vector2d& localPosition = Vector2d::Zero(),
                         const Vector2d &forceValue = Vector2d::Zero());
 
     void calcForce(bool calcVariances) override;
@@ -90,7 +78,7 @@ class CircularMotor : public Force
 
 public:
     /** Constructs CircularMotor */
-    explicit CircularMotor(Object* body = 0, const Vector2d& localPosition = Vector2d::Zero(),
+    explicit CircularMotor(Object* body = nullptr, const Vector2d& localPosition = Vector2d::Zero(),
                                             double torqueValue = 0);
 
     void calcForce(bool calcVariances) override;
